@@ -82,9 +82,9 @@ geome.fit <- function(X, Y, rs, strats, offset, init, max.survs,
                   #
                   conver = integer(1),
                   f.conver = integer(1),
-                  fail = integer(1),
-                  #DUP = FALSE,
-                  PACKAGE = "eha")
+                  fail = integer(1)
+                  ##DUP = FALSE
+                  )
   if (fit$fail){
       out <- paste("Singular hessian; suspicious variable No. ",
                    as.character(fit$fail), ":\n",
@@ -121,9 +121,8 @@ geome.fit <- function(X, Y, rs, strats, offset, init, max.survs,
                                         #
                       as.double(score),       ## 'score'
                       as.double(hazard),
-                      resid = double(nn),
-                                        #DUP = FALSE,
-                      PACKAGE = "eha"
+                      resid = double(nn)
+                      ##DUP = FALSE,
                       )$resid
   }
       
@@ -178,9 +177,9 @@ geome.fit <- function(X, Y, rs, strats, offset, init, max.survs,
                            double(ncov * ncov),
                                         #
                            conver = integer(1),
-                           fail = integer(1),
-                                        #DUP = FALSE,
-                           PACKAGE = "eha")
+                           fail = integer(1)
+                           ##DUP = FALSE,
+                           )
       bootstrap <- matrix(fit.boot$boot.sample, ncol = ncov, byrow = TRUE)
       boot.sd <- matrix(fit.boot$boot.sd, ncol = ncov, byrow = TRUE)
     }      
