@@ -194,6 +194,8 @@ mlreg.fit <- function(X, Y, rs, strats, offset, init, max.survs,
        score = fit$sctest,
        linear.predictors = lp,
        residuals = resid,
+       noOfRisksets = rs$antrs,
+       risktimes = rs$risktimes,
        hazard = hazard,
        means = apply(X, 2, mean),
        bootstrap = bootstrap,
